ytree\.tree\_farm\.ancestry\_filter\.add\_ancestry\_filter
==========================================================

.. currentmodule:: ytree.tree_farm.ancestry_filter

.. autofunction:: add_ancestry_filter